##  Supported Configurations
**Tip**
The integration between SAP LeanIX and ServiceNow is compatible with CSDM 4.0 guidelines
As of the last update of this documentation, our suggested default configuration below is in alignment with CSDM 4.0. Please feel free to reach out to your CSM for any specific questions.
Before implementing the integration, it is recommended to review the current maturity level of the ServiceNow Instance to be connected. The maturity and availability of modules within the ServiceNow instance will implicate what configurations can be used and not used while connecting with SAP LeanIX.
The following decision table provides suggested configuration workflows.
Maturity State | Modules Required | Flow
---|---|---
Ready to sync Applications, Business Capabilities, and their relationships to ServiceNow. | n/a |  [Default Mapping](https://help.sap.com/docs/leanix/ea/servicenow-integration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275cad557a441014a42ef5e0f9d2887f__default_mapping) Note - The IT Component section of the flowchart does not apply.
Ready to sync IT Components of category Hardware, Software, and their relationships with Applications from ServiceNow. | Software Asset Management (SAM) Discovery Service. The link between the Software Discovery Model and the Software Product Model record required through the model_id reference field. |  [Default Mapping](https://help.sap.com/docs/leanix/ea/servicenow-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Fundamentals of the SAP LeanIX integration with ServiceNow \(CMDB\).")
(Same as above) Ready to sync IT Components of category Hardware, Software, and their relationships with Applications from ServiceNow. | Software Asset Management Professional (SAM Pro) Discovery Service. |  [Default Mapping](https://help.sap.com/docs/leanix/ea/servicenow-integration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275cad557a441014a42ef5e0f9d2887f__default_mapping) [Default Mapping (SAM Pro)](https://help.sap.com/docs/leanix/ea/servicenow-integration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275cad557a441014a42ef5e0f9d2887f__default_mapping_sam_pro) - Recommended for large ServiceNow Instances.


Applications in SAP LeanIX are connected to Business Applications in ServiceNow. IT components in SAP LeanIX are imported from the ServiceNow table Product Models, which is the inventory of Hardware and Software Models in ServiceNow.
As a best practice for CSDM 4.0 modeling, we recommend including business application and deployment as subtypes for application fact sheets and map them to Business Application and Application Service in ServiceNow respectively. In addition to this, other components related to CSDM can be managed in ServiceNow. For more information, see optional[Application Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD#loio275892ca7a441014ab86c9b2e6382a33__application_fact_sheet_subtypes).
